@@ -1,5 +1,6 @@
 from typing import List, Dict
 
+from versioning import get_available_version
 from wkcuber import downsample_mags
 from .compress import compress_mag_inplace
 from .metadata import refresh_metadata
@@ -26,7 +27,7 @@ def detect_present_mags(target_path: Path) -> Dict[Path, List[Mag]]:
         mag_paths = list([p for p in layer_p.iterdir() if p.is_dir()])
         for mag_p in mag_paths:
             try:
-                mag = Mag(mag_p.stem)
+                mag = Mag(mag_p.name)
             except (AssertionError, ValueError) as _:
                 continue
             layer_path_to_mags[layer_p].append(mag)
@@ -58,6 +59,10 @@ def create_parser() -> ArgumentParser:
         action="store_true",
     )
 
+    parser.add_argument(
+        "--version", action="version", version=f"wkcuber {get_available_version()}"
+    )
+
     parser.add_argument("--name", "-n", help="Name of the dataset", default=None)
     add_isotropic_flag(parser)
     add_sampling_mode_flag(parser)
@@ -80,12 +85,12 @@ def main(args: Namespace) -> None:
 
     if not args.no_compress:
         for (layer_path, mags) in layer_path_to_mags.items():
-            layer_name = layer_path.stem
+            layer_name = layer_path.name
             for mag in mags:
                 compress_mag_inplace(args.target_path, layer_name, mag, args)
 
     for (layer_path, mags) in layer_path_to_mags.items():
-        layer_name = layer_path.stem
+        layer_name = layer_path.name
         mags.sort()
         downsample_mags(
             path=args.target_path,
