@@ -1,10 +1,10 @@
 import logging
 from argparse import ArgumentParser, Namespace
 from pathlib import Path
-from typing import Any, Callable
+from typing import Any, Callable, Optional
 
 from wkcuber.api.dataset import Dataset
-from wkcuber.api.bounding_box import BoundingBox, BoundingBoxNamedTuple
+from webknossos.geometry import BoundingBox, Vec3Int
 import numpy as np
 
 from wkcuber.mag import Mag
@@ -21,7 +21,8 @@ from .metadata import detect_resolutions, detect_bbox, detect_layers
 import functools
 from .compress import BACKUP_EXT
 
-CHUNK_SIZE = 1024
+
+CHUNK_SIZE = Vec3Int.full(1024)
 
 
 def named_partial(func: Callable, *args: Any, **kwargs: Any) -> Callable:
@@ -63,7 +64,7 @@ def assert_equality_for_chunk(
     target_path: Path,
     layer_name: str,
     mag: Mag,
-    sub_box: BoundingBoxNamedTuple,
+    sub_box: BoundingBox,
 ) -> None:
     wk_dataset = Dataset(source_path)
     layer = wk_dataset.get_layer(layer_name)
@@ -80,7 +81,7 @@ def assert_equality_for_chunk(
 
 
 def check_equality(
-    source_path: Path, target_path: Path, args: Namespace = None
+    source_path: Path, target_path: Path, args: Optional[Namespace] = None
 ) -> None:
 
     logging.info(f"Comparing {source_path} with {target_path}")
@@ -132,9 +133,7 @@ def check_equality(
             logging.info(f"Start verification of {layer_name} in mag {mag} in {bbox}")
 
             with get_executor_for_args(args) as executor:
-                boxes = list(
-                    bbox.chunk([CHUNK_SIZE, CHUNK_SIZE, CHUNK_SIZE], [CHUNK_SIZE])
-                )
+                boxes = list(bbox.chunk(CHUNK_SIZE, CHUNK_SIZE))
                 assert_fn = named_partial(
                     assert_equality_for_chunk, source_path, target_path, layer_name, mag
                 )
