@@ -8,10 +8,11 @@ from typing import Tuple, Optional, Union, cast
 import nibabel as nib
 import numpy as np
 
+from webknossos.dataset import LayerCategoryType
+from webknossos.dataset.defaults import DEFAULT_WKW_FILE_LEN
 from wkcuber.api.dataset import Dataset
 from wkcuber.api.bounding_box import BoundingBox
 from wkcuber.utils import (
-    DEFAULT_WKW_FILE_LEN,
     DEFAULT_WKW_VOXELS_PER_BLOCK,
     add_verbose_flag,
     add_scale_flag,
@@ -127,7 +128,7 @@ def convert_nifti(
     scale: Tuple[float, ...],
     is_segmentation_layer: bool = False,
     file_len: int = DEFAULT_WKW_FILE_LEN,
-    bbox_to_enforce: BoundingBox = None,
+    bbox_to_enforce: Optional[BoundingBox] = None,
     use_orientation_header: bool = False,
     flip_axes: Optional[Union[int, Tuple[int, ...]]] = None,
 ) -> None:
@@ -149,7 +150,9 @@ def convert_nifti(
         if is_segmentation_layer
         else {}
     )
-    category_type = "segmentation" if is_segmentation_layer else "color"
+    category_type: LayerCategoryType = (
+        "segmentation" if is_segmentation_layer else "color"
+    )
     logging.debug(f"Assuming {category_type} as layer type for {layer_name}")
 
     if len(source_nifti.shape) == 3:
@@ -229,7 +232,7 @@ def convert_folder_nifti(
     segmentation_subpath: str,
     scale: Tuple[float, ...],
     use_orientation_header: bool = False,
-    bbox_to_enforce: BoundingBox = None,
+    bbox_to_enforce: Optional[BoundingBox] = None,
     flip_axes: Optional[Union[int, Tuple[int, ...]]] = None,
 ) -> None:
     paths = list(source_folder_path.rglob("**/*.nii"))
