@@ -1,6 +1,7 @@
 import json
-import os
-import re
+from webknossos.dataset._utils.infer_bounding_box_existing_files import (
+    parse_cube_file_name,
+)
 import wkw
 import logging
 import numpy as np
@@ -10,6 +11,8 @@ from argparse import ArgumentParser
 from glob import iglob
 from os import path, listdir
 from typing import Optional, Tuple, Iterable, Generator
+
+from webknossos.dataset.layer import LayerCategoryType
 from .mag import Mag
 from typing import List
 from .utils import add_verbose_flag, setup_logging, add_scale_flag
@@ -179,13 +182,9 @@ def convert_dtype_to_element_class(dtype: np.dtype) -> str:
     element_class_to_dtype_map = {
         "float": np.float32,
         "double": np.float64,
-        "uint8": np.uint8,
-        "uint16": np.uint16,
-        "uint32": np.uint32,
-        "uint64": np.uint64,
     }
     conversion_map = {v: k for k, v in element_class_to_dtype_map.items()}
-    return conversion_map.get(dtype, str(dtype))
+    return conversion_map.get(dtype, str(np.dtype(dtype)))
 
 
 def detect_mag_path(
@@ -235,15 +234,6 @@ def detect_bbox(dataset_path: Path, layer: str, mag: Mag = Mag(1)) -> Optional[d
     def list_files(layer_path: str) -> Iterable[str]:
         return iglob(path.join(layer_path, "*", "*", "*.wkw"), recursive=True)
 
-    def parse_cube_file_name(filename: str) -> Tuple[int, int, int]:
-        CUBE_REGEX = re.compile(
-            fr"z(\d+){re.escape(os.path.sep)}y(\d+){re.escape(os.path.sep)}x(\d+)(\.wkw)$"
-        )
-        m = CUBE_REGEX.search(filename)
-        if m is not None:
-            return int(m.group(3)), int(m.group(2)), int(m.group(1))
-        raise RuntimeError(f"Failed to parse cube file name from {filename}")
-
     def list_cubes(layer_path: str) -> Iterable[Tuple[int, int, int]]:
         return (parse_cube_file_name(f) for f in list_files(layer_path))
 
@@ -264,7 +254,7 @@ def detect_bbox(dataset_path: Path, layer: str, mag: Mag = Mag(1)) -> Optional[d
     }
 
 
-def detect_resolutions(dataset_path: Path, layer: str) -> Generator:
+def detect_resolutions(dataset_path: Path, layer: str) -> Generator[Mag, None, None]:
     for mag in listdir(path.join(dataset_path, layer)):
         try:
             yield Mag(mag)
@@ -276,7 +266,7 @@ def detect_standard_layer(
     dataset_path: Path,
     layer_name: str,
     exact_bounding_box: Optional[dict] = None,
-    category: str = "color",
+    category: LayerCategoryType = "color",
     layer_view_configuration: Optional[dict] = None,
 ) -> dict:
     # Perform metadata detection for well-known layers
@@ -304,7 +294,7 @@ def detect_standard_layer(
 
     resolutions = [
         {
-            "resolution": mag.to_array(),
+            "resolution": mag.to_list(),
             "cubeLength": detect_cubeLength(dataset_path, layer_name, mag),
         }
         for mag in mags
@@ -344,7 +334,7 @@ def detect_segmentation_layer(
     layer_name: str,
     max_id: int,
     compute_max_id: bool = False,
-    exact_bounding_box: dict = None,
+    exact_bounding_box: Optional[dict] = None,
 ) -> dict:
     layer_info = detect_standard_layer(
         dataset_path, layer_name, exact_bounding_box, category="segmentation"
